@@ -63,6 +63,11 @@ typedef struct {
 /* Global data                                                                */
 /*----------------------------------------------------------------------------*/
 
+conf_table_t conf_table[2] = {
+    {CONF_TYPE_BOOL, "autohide", N_("Hide icon when no devices"),   NULL},
+    {CONF_TYPE_NONE,  NULL,      NULL,                              NULL}
+};
+
 /*----------------------------------------------------------------------------*/
 /* Prototypes                                                                 */
 /*----------------------------------------------------------------------------*/
@@ -112,7 +117,7 @@ static gboolean was_ejected (EjecterPlugin *ej, GDrive *drive)
         if (el->drv == drive)
         {
             ejected = TRUE;
-            if (el->seq != -1) lxpanel_notify_clear (el->seq);
+            if (el->seq != -1) wrap_notify_clear (el->seq);
             ej->ejdrives = g_list_remove (ej->ejdrives, el);
             g_free (el);
         }
@@ -240,7 +245,11 @@ static void handle_drive_out (GtkWidget *, GDrive *drive, gpointer data)
     DEBUG ("DRIVE REMOVED %s", g_drive_get_name (drive));
 
     if (was_mounted (ej, drive) && !was_ejected (ej, drive))
-        lxpanel_notify (ej->panel, _("Drive was removed without ejecting\nPlease use menu to eject before removal"));
+    {
+        // filter Pico loader
+        if (strncmp (g_drive_get_name (drive), "RPI RP2", 7))
+            wrap_notify (ej->panel, _("Drive was removed without ejecting\nPlease use menu to eject before removal"));
+    }
 
     if (ej->menu && gtk_widget_get_visible (ej->menu)) show_menu (ej);
     update_icon (ej);
@@ -269,13 +278,13 @@ static void eject_done (GObject *source_object, GAsyncResult *res, gpointer data
     {
         DEBUG ("EJECT COMPLETE");
         buffer = g_strdup_printf (_("%s has been ejected\nIt is now safe to remove the device"), g_drive_get_name (drv));
-        add_seq_for_drive (ej, drv, lxpanel_notify (ej->panel, buffer));
+        add_seq_for_drive (ej, drv, wrap_notify (ej->panel, buffer));
     }
     else
     {
         DEBUG ("EJECT FAILED");
         buffer = g_strdup_printf (_("Failed to eject %s\n%s"), g_drive_get_name (drv), err->message);
-        lxpanel_notify (ej->panel, buffer);
+        wrap_notify (ej->panel, buffer);
     }
     g_free (buffer);
 }
@@ -369,6 +378,7 @@ static GtkWidget *create_menuitem (EjecterPlugin *ej, GDrive *d)
     char buffer[1024];
     GList *vols;
     GVolume *v;
+    GIcon *ic;
     GtkWidget *item, *icon, *eject;
 
     vols = g_drive_get_volumes (d);
@@ -387,7 +397,9 @@ static GtkWidget *create_menuitem (EjecterPlugin *ej, GDrive *d)
         }
     }
     strcat (buffer, ")");
-    icon = gtk_image_new_from_gicon (g_drive_get_icon (d), GTK_ICON_SIZE_BUTTON);
+    ic = g_drive_get_icon (d);
+    icon = gtk_image_new_from_gicon (ic, wrap_icon_size (ej) >= 32 ? GTK_ICON_SIZE_LARGE_TOOLBAR : GTK_ICON_SIZE_BUTTON);
+    g_object_unref (ic);
 
     item = wrap_new_menu_item (ej, buffer, 40, NULL);
     lxpanel_plugin_update_menu_icon (item, icon);
@@ -415,7 +427,7 @@ static void ejecter_button_clicked (GtkWidget *, EjecterPlugin * ej)
 /* Handler for system config changed message from panel */
 void ejecter_update_display (EjecterPlugin * ej)
 {
-    wrap_set_taskbar_icon (ej, ej->tray_icon, "media-eject");
+    wrap_set_taskbar_icon (ej, ej->tray_icon, "plugin-eject");
     update_icon (ej);
 }
 
@@ -451,7 +463,7 @@ void ejecter_init (EjecterPlugin *ej)
     /* Allocate icon as a child of top level */
     ej->tray_icon = gtk_image_new ();
     gtk_container_add (GTK_CONTAINER (ej->plugin), ej->tray_icon);
-    wrap_set_taskbar_icon (ej, ej->tray_icon, "media-eject");
+    wrap_set_taskbar_icon (ej, ej->tray_icon, "plugin-eject");
     gtk_widget_set_tooltip_text (ej->tray_icon, _("Select a drive in menu to eject safely"));
 
     /* Set up button */
@@ -502,8 +514,12 @@ static GtkWidget *ejecter_constructor (LXPanel *panel, config_setting_t *setting
     ej->plugin = gtk_button_new ();
     lxpanel_plugin_set_data (ej->plugin, ej, ejecter_destructor);
 
+    /* Set config defaults */
+    ej->autohide = TRUE;
+
     /* Read config */
-    if (!config_setting_lookup_int (ej->settings, "AutoHide", &ej->autohide)) ej->autohide = TRUE;
+    conf_table[0].value = (void *) &ej->autohide;
+    lxplug_read_settings (ej->settings, conf_table);
 
     ejecter_init (ej);
 
@@ -541,7 +557,7 @@ static gboolean ejecter_apply_configuration (gpointer user_data)
 {
     EjecterPlugin *ej = lxpanel_plugin_get_data (GTK_WIDGET (user_data));
 
-    config_group_set_int (ej->settings, "AutoHide", ej->autohide);
+    lxplug_write_settings (ej->settings, conf_table);
 
     ejecter_update_display (ej);
     return FALSE;
@@ -550,19 +566,17 @@ static gboolean ejecter_apply_configuration (gpointer user_data)
 /* Display configuration dialog */
 static GtkWidget *ejecter_configure (LXPanel *panel, GtkWidget *plugin)
 {
-    EjecterPlugin *ej = lxpanel_plugin_get_data (plugin);
-
-    return lxpanel_generic_config_dlg(_("Ejecter"), panel,
+    return lxpanel_generic_config_dlg_new (_(PLUGIN_TITLE), panel,
         ejecter_apply_configuration, plugin,
-        _("Hide icon when no devices"), &ej->autohide, CONF_TYPE_BOOL,
-        NULL);
+        conf_table);
 }
 
-FM_DEFINE_MODULE (lxpanel_gtk, ejecter)
+int module_lxpanel_gtk_version = 1;
+char module_name[] = PLUGIN_NAME;
 
 /* Plugin descriptor */
 LXPanelPluginInit fm_module_init_lxpanel_gtk = {
-    .name = N_("Ejecter"),
+    .name = PLUGIN_TITLE,
     .description = N_("Ejects mounted drives"),
     .new_instance = ejecter_constructor,
     .reconfigure = ejecter_configuration_changed,
